@@ -4,6 +4,7 @@ from dataclasses import dataclass
 from annotell.input_api.model.abstract.abstract_models import Response
 from annotell.input_api.util import ts_to_dt
 
+
 @dataclass
 class Annotation(Response):
     input_uuid: str
@@ -14,10 +15,9 @@ class Annotation(Response):
     @staticmethod
     def from_json(js: dict):
         return Annotation(
-                input_uuid=js["inputUuid"],
-                annotation_type=js["annotationType"],
-                created=ts_to_dt(js["created"]),
-                content=js["content"])
+            input_uuid=js["inputUuid"], annotation_type=js["annotationType"], created=ts_to_dt(js["created"]), content=js["content"]
+        )
+
 
 @dataclass
 class PartialAnnotation(Response):
@@ -29,14 +29,8 @@ class PartialAnnotation(Response):
     @staticmethod
     def from_json(js: dict):
         return PartialAnnotation(
-            input_uuid=js["inputUuid"],
-            annotation_type=js["annotationType"],
-            created=ts_to_dt(js["created"]),
-            uri=js["uri"])
+            input_uuid=js["inputUuid"], annotation_type=js["annotationType"], created=ts_to_dt(js["created"]), uri=js["uri"]
+        )
 
     def to_annotation(self, content: Dict) -> Annotation:
-        return Annotation(
-            input_uuid=self.input_uuid,
-            annotation_type=self.annotation_type,
-            created=self.created,
-            content=content)
+        return Annotation(input_uuid=self.input_uuid, annotation_type=self.annotation_type, created=self.created, content=content)
